# -*- coding: utf-8 -*-

"""
apimaticcalculator

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class OperationTypeEnum(object):

    """Implementation of the 'OperationType' enum.

    Possible operators are sum, subtract, multiply, divide

    Attributes:
        SUM: TODO: type description here.
        SUBTRACT: TODO: type description here.
        MULTIPLY: TODO: type description here.
        DIVIDE: TODO: type description here.

    """

    SUM = 'SUM'

    SUBTRACT = 'SUBTRACT'

    MULTIPLY = 'MULTIPLY'

    DIVIDE = 'DIVIDE'
